==> haskell-hoauth2_1.7.2.orig.tar.gz: hoauth2-1.7.2/example/Keys.hs <==
{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE QuasiQuotes       #-}

module Keys where

import           Data.ByteString      (ByteString)
import           Network.OAuth.OAuth2
import           URI.ByteString.QQ

weiboKey :: OAuth2
weiboKey = OAuth2 { oauthClientId = "1962132691"
                  , oauthClientSecret = "a2ad30383bdff9bcb12be6a3d30deeb1"
                  , oauthCallback = Just [uri|http://127.0.0.1:9988/oauth2/callback|]
                  , oauthOAuthorizeEndpoint = [uri|https://api.weibo.com/oauth2/authorize|]
                  , oauthAccessTokenEndpoint = [uri|https://api.weibo.com/oauth2/access_token|]
                  }

-- | http://developer.github.com/v3/oauth/
githubKey :: OAuth2
githubKey = OAuth2 { oauthClientId = "bf86d338485a96a93c88"
                   , oauthClientSecret = "a1c00dada665dc00aa6fafe0495c7c885f82d1ce"
                   , oauthCallback = Just [uri|http://127.0.0.1:9988/oauth2/callback|]
                   , oauthOAuthorizeEndpoint = [uri|https://github.com/login/oauth/authorize|]
                   , oauthAccessTokenEndpoint = [uri|https://github.com/login/oauth/access_token|]
                   }

-- | oauthCallback = Just "https://developers.google.com/oauthplayground"
googleKey :: OAuth2
googleKey = OAuth2 { oauthClientId = "886894027376.apps.googleusercontent.com"
                   , oauthClientSecret = "27w98gwGB1h8N5a6JQ2bT_nm"
                   , oauthCallback = Just [uri|http://127.0.0.1:9988/oauth2/callback|]
                   , oauthOAuthorizeEndpoint = [uri|https://accounts.google.com/o/oauth2/auth|]
                   , oauthAccessTokenEndpoint = [uri|https://www.googleapis.com/oauth2/v3/token|]
                   }

{-
googleServiceAccount :: GoogleServiceAccount
googleServiceAccount = GoogleServiceAccount
  { saPrivateKey = "-----BEGIN PRIVATE KEY-----\nMIIEvwIBADANBgkqhkiG9w0BAQEFAASCBKkwggSlAgEAAoIBAQDfu/z7ASRGrQus\ngWABWNX/EKgE8NlEUoHUeDWCTpXVj6PmiEDGyRaBNqR+6fQmwBMD/ItpISTGT31/\nfdqhKAdJOaYGNvWNYxx1uWYm0HP1YU7OkfFt8YgROu8gGz7+mdseXs/3bMhjlbk9\nPKmBiU46VRFWn7QaAp9YiVGghZp/LcawC+urmWdYnpkl+P4C4u+YtszmCMql842M\nT4nK8jlraxvUT/XM+97UXKwiGL8sPiPKGEthAFiXHNRVgnDibnJ2Etw7zPbZ6FB+\nvHL1SkuSnE7C358RTkuz56Tvf6ETgOGDIJ9HpZlgT6hrsWcAOh8UZ34Q5QzinhtP\n5BdgQxnjAgMBAAECggEBAJqfxFYA0v5ZZ+D/xMcJi1PtQgGwJqf2Ua3yqiB1iU4A\nKKkRb5syrG/+wK7Jp6gEROATcJHmixDXLQeohimsjWSJB/nxj8D4R1oBGN0oYYur\nhZhz+qQeMgieb1cEHYQ99tbFdfss3k0c09nDi+5vY3YjBomUdBcpytCYjqZez4im\nYoZjA6ijb5BduCQO2YOJpjiHbSrTV05Zr/xfHgafkbRx04jHA7OdJM6x5giRcMBn\n5BYNGPUkM6mGpeTeCZjTsOqvXcckuyR8P4wzoG3J8grnXgGR17d829t0bi5X/Jym\nwj5707lvIqu+WcfUfXDDYkZNhe5S9PWpT1uqaOGWElECgYEA738wclTGRNboYLsx\noT6HCOEKNFiY/4DMV65nugSnHBIl4amLwm4+0v669F8F28U2xhihp+RfPC4Fjd62\nfJ9hlYg6NiEqReJfXhs5OcvMBjmBFUR046/kOGyEj6D2yn3LTXoiWI8tHaS0Ucmu\nwF4Lp0/Rk/ofQrFB7q1a0OBeTakCgYEA7ya+IMo0t4lRYl+x8A7ouuJwnK1VjkkC\nkloCAEsnVznb2BsHJCsF0fPPU3f+kqhYqD0qQCfbwhYGragt603a/BqXnnQyE9T/\nnLqSGgctY/Xr06HbOr+aZ4QLKsTfD6IkTC82WAJD3J8hptLaqqDMORluI6xchKEL\nNUV8uvX7qqsCgYEAtKo/w5+LyZZMydusfrSKbPpGFmLXV7azb1lTShIEdbqC9Q5P\nLaa4obYjFgEwjC7jOOCP4fT2mpElA3aENtKMbJ7NOtQd7YXs5zKmIqFIEVIDvCVd\n//xJrv69qROF2A649IMzsZagNAJxPFlmCBtpsxcVRAmk10ycLg57uaHnwbECgYEA\nrtqn1rehVbQ74e5P3lI4TTP03ElLra2qCLFwlyBb0kXGfLo+PW6LYdeedcvdQQN/\nVvrpomDCJ6UNGvlFIa8Z9ovG4Z7ZYnCwt7odypQG1vhehazo6ope7WK4+3tYEEkf\nuugmFrEJRwy+gQfXwzuwNetnAQQr3PkWhcuZh+UELeMCgYAPoQK1LETBLFsUBWhh\nHc5VrnQBykn9GMRPXKR4pq5MK8p8o2QwfL5hNlZNeTKPWdP0QtMuIH9gxRuqvbrF\nXEO8RmZmoNtznh/Ax7+S62g72iLzF1/C8j3g8hWJUeGlU8LAJsZVTSma3t/vEQZM\nQqydJfwXJMTkh4nslALJZ9S4bw==\n-----END PRIVATE KEY-----\n"
  , saEmail = "testoauth2sa@api-project-886894027376.iam.gserviceaccount.com"
  , saScope = [ "https://www.googleapis.com/auth/prediction"
              , "https://www.googleapis.com/auth/drive"
              ]
  , saAuthEndpoint = "https://www.googleapis.com/oauth2/v4/token"
  , saExpireTime = Nothing
  , saDelegateEmail = Nothing
  }
-}

facebookKey :: OAuth2
facebookKey = OAuth2 { oauthClientId = "414630782030965"
                     , oauthClientSecret = "0e648eae100da4d03f16594f231fc1d0"
                     , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                     , oauthOAuthorizeEndpoint = [uri|https://www.facebook.com/dialog/oauth|]
                     , oauthAccessTokenEndpoint = [uri|https://graph.facebook.com/v2.12/oauth/access_token|]
                     }

doubanKey :: OAuth2
doubanKey = OAuth2 { oauthClientId = "02a914cf299ca31607fb3e6d7cd5e942"
                   , oauthClientSecret = "3c0fdef13b0dd271"
                   , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                   , oauthOAuthorizeEndpoint = [uri|https://www.douban.com/service/auth2/auth|]
                   , oauthAccessTokenEndpoint = [uri|https://www.douban.com/service/auth2/token|]
                   }

fitbitKey :: OAuth2
fitbitKey = OAuth2 { oauthClientId = "229LN9"
                   , oauthClientSecret = "2f4aa9a275c2d4bb9eb616efbd2c1311"
                   , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                   , oauthOAuthorizeEndpoint = [uri|https://www.fitbit.com/oauth2/authorize|]
                   , oauthAccessTokenEndpoint = [uri|https://api.fitbit.com/oauth2/token|]
                   }

stackexchangeAppKey :: ByteString
stackexchangeAppKey = "LZvAveRFYw8lgNluEU2pDQ(("

stackexchangeKey :: OAuth2
stackexchangeKey = OAuth2 { oauthClientId = "7185"
                          , oauthClientSecret = "K5hK)ET*dbFGFmNFVtqIyA(("
                          , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                          , oauthOAuthorizeEndpoint = [uri|https://stackexchange.com/oauth|]
                          , oauthAccessTokenEndpoint = [uri|https://stackexchange.com/oauth/access_token/json|]
                          }

dropboxKey :: OAuth2
dropboxKey = OAuth2 { oauthClientId = "zbyxxox19gz6dgg"
                    , oauthClientSecret = "ihhui0ysp85oi8s"
                    , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                    , oauthOAuthorizeEndpoint = [uri|https://www.dropbox.com/1/oauth2/authorize|]
                    , oauthAccessTokenEndpoint = [uri|https://api.dropboxapi.com/oauth2/token|]
                    }

oktaKey :: OAuth2
oktaKey = OAuth2 { oauthClientId = "0oad3popatwUIhWV40h7"
                 , oauthClientSecret = "YFqXRjtsy7IYRbueiG2tcgHzhaawLccxqq5ruPfN"
                 , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                 , oauthOAuthorizeEndpoint = [uri|https://dev-148986.oktapreview.com/oauth2/v1/authorize|]
                 , oauthAccessTokenEndpoint = [uri|https://dev-148986.oktapreview.com/oauth2/v1/token|]
                 }

linkedinKey :: OAuth2
linkedinKey = OAuth2 { oauthClientId = "86r7dx3b0piy56"
                     , oauthClientSecret = "lBb5kA5lpggHT0Ne"
                     , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                     , oauthOAuthorizeEndpoint = [uri|https://www.linkedin.com/oauth/v2/authorization|]
                     , oauthAccessTokenEndpoint = [uri|https://www.linkedin.com/oauth/v2/accessToken|]
                     }

==> haskell-hoauth2_1.8.7.orig.tar.gz: hoauth2-1.8.7/example/Keys.hs <==
{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE QuasiQuotes       #-}

module Keys where

import           Data.ByteString      (ByteString)
import           Network.OAuth.OAuth2
import           URI.ByteString.QQ

weiboKey :: OAuth2
weiboKey = OAuth2 { oauthClientId = "1962132691"
                  , oauthClientSecret = "a2ad30383bdff9bcb12be6a3d30deeb1"
                  , oauthCallback = Just [uri|http://127.0.0.1:9988/oauth2/callback|]
                  , oauthOAuthorizeEndpoint = [uri|https://api.weibo.com/oauth2/authorize|]
                  , oauthAccessTokenEndpoint = [uri|https://api.weibo.com/oauth2/access_token|]
                  }

-- | http://developer.github.com/v3/oauth/
githubKey :: OAuth2
githubKey = OAuth2 { oauthClientId = "bf86d338485a96a93c88"
                   , oauthClientSecret = "a1c00dada665dc00aa6fafe0495c7c885f82d1ce"
                   , oauthCallback = Just [uri|http://127.0.0.1:9988/oauth2/callback|]
                   , oauthOAuthorizeEndpoint = [uri|https://github.com/login/oauth/authorize|]
                   , oauthAccessTokenEndpoint = [uri|https://github.com/login/oauth/access_token|]
                   }

-- | oauthCallback = Just "https://developers.google.com/oauthplayground"
googleKey :: OAuth2
googleKey = OAuth2 { oauthClientId = "886894027376.apps.googleusercontent.com"
                   , oauthClientSecret = "27w98gwGB1h8N5a6JQ2bT_nm"
                   , oauthCallback = Just [uri|http://127.0.0.1:9988/oauth2/callback|]
                   , oauthOAuthorizeEndpoint = [uri|https://accounts.google.com/o/oauth2/auth|]
                   , oauthAccessTokenEndpoint = [uri|https://www.googleapis.com/oauth2/v3/token|]
                   }


facebookKey :: OAuth2
facebookKey = OAuth2 { oauthClientId = "414630782030965"
                     , oauthClientSecret = "0e648eae100da4d03f16594f231fc1d0"
                     , oauthCallback = Just [uri|http://127.0.0.1:9988/oauth2/callback|]
                     , oauthOAuthorizeEndpoint = [uri|https://www.facebook.com/dialog/oauth|]
                     , oauthAccessTokenEndpoint = [uri|https://graph.facebook.com/v2.3/oauth/access_token|]
                     }

doubanKey :: OAuth2
doubanKey = OAuth2 { oauthClientId = "02a914cf299ca31607fb3e6d7cd5e942"
                   , oauthClientSecret = "3c0fdef13b0dd271"
                   , oauthCallback = Just [uri|http://localhost:9999/oauthCallback|]
                   , oauthOAuthorizeEndpoint = [uri|https://www.douban.com/service/auth2/auth|]
                   , oauthAccessTokenEndpoint = [uri|https://www.douban.com/service/auth2/token|]
                   }

fitbitKey :: OAuth2
fitbitKey = OAuth2 { oauthClientId = "229LN9"
                   , oauthClientSecret = "2f4aa9a275c2d4bb9eb616efbd2c1311"
                   , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                   , oauthOAuthorizeEndpoint = [uri|https://www.fitbit.com/oauth2/authorize|]
                   , oauthAccessTokenEndpoint = [uri|https://api.fitbit.com/oauth2/token|]
                   }

-- fix key from your application edit page
-- https://stackapps.com/apps/oauth
stackexchangeAppKey :: ByteString
stackexchangeAppKey = "xxxxxx"

stackexchangeKey :: OAuth2
stackexchangeKey = OAuth2 { oauthClientId = "7185"
                          , oauthClientSecret = "K5hK)ET*dbFGFmNFVtqIyA(("
                          , oauthCallback = Just [uri|http://c.haskellcn.org/cb|]
                          , oauthOAuthorizeEndpoint = [uri|https://stackexchange.com/oauth|]
                          , oauthAccessTokenEndpoint = [uri|https://stackexchange.com/oauth/access_token|]
                          }

dropboxKey :: OAuth2
dropboxKey = OAuth2 { oauthClientId = "zbyxxox19gz6dgg"
                    , oauthClientSecret = "ihhui0ysp85oi8s"
                    , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                    , oauthOAuthorizeEndpoint = [uri|https://www.dropbox.com/1/oauth2/authorize|]
                    , oauthAccessTokenEndpoint = [uri|https://api.dropboxapi.com/oauth2/token|]
                    }

oktaKey :: OAuth2
oktaKey = OAuth2 { oauthClientId = "0oad3popatwUIhWV40h7"
                 , oauthClientSecret = "YFqXRjtsy7IYRbueiG2tcgHzhaawLccxqq5ruPfN"
                 , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                 , oauthOAuthorizeEndpoint = [uri|https://dev-148986.oktapreview.com/oauth2/v1/authorize|]
                 , oauthAccessTokenEndpoint = [uri|https://dev-148986.oktapreview.com/oauth2/v1/token|]
                 }

azureADKey :: OAuth2
azureADKey = OAuth2 { oauthClientId = "xxx"
                    , oauthClientSecret = "xxx"
                    , oauthCallback = Just [uri|http://localhost:9988/oauth2/callback|]
                    , oauthOAuthorizeEndpoint = [uri|https://login.windows.net/common/oauth2/authorize|]
                    , oauthAccessTokenEndpoint = [uri|https://login.windows.net/common/oauth2/token|]
                    }
